function [vars,varexo]=f_simul_end(params,moments)

%Calculates steady state values using the parameters
%Input:     params: structure of parameters
%Output:    vars: structure of steady state values

%Loading parameters and creating structure for easy transfer
load ../Settings/params.mat params moments switches;

%Creating variables from the params structure
params_names     =   fieldnames(params);
nn=length(params_names);
for ii=1:nn
    eval([params_names{ii} '=params.' params_names{ii} ';']);
end;

moments_names  =   fieldnames(moments);
pp  =   length(moments_names);
for ii=1:pp
    eval([moments_names{ii} '=moments.' moments_names{ii} ';']);
end;

%Calculating the trajectories of the epidemic variables
%run ../epi_models/epidemic_models.m;
load ../Settings/SIR.mat ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculating steady state values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%dummy shock
    %dummy=0;

%Targets
phi     =   moments.phi_mom;        %steady state premium
RkmR    =   moments.RkmR_mom;       %steady state leverage
    
%Epidemiological block (to be coordinate with Epidemic code)
%S      = sol_SIR_eu(1);   
Itilde = sol_SIR_eu(2);
%Rtilde = sol_SIR_eu(3);
L      = 1-Itilde;

%Households
R   =   1/betta;
Lambda = betta;

%Producers
Pi          =   1;
Q       =   1;
Pistar =   ((1-theta_p*Pi^((chi-1)*(1-epsilon_p)))/(1-theta_p))^(1/(1-epsilon_p));
vp      =   (1-theta_p*Pistar^(-epsilon_p))/(1-theta_p*Pi^(-epsilon_p*chi));
Pm  = (epsilon_p-1)/epsilon_p*Pistar*(1-betta*theta_p*Pi^((chi-1)*(1-epsilon_p)))/(1-betta*theta_p*Pi^((chi-1)*(-epsilon_p)));
K   =   (Q*(RkmR - (1-delta) + R)/(alfa*Pm*L^(1-alfa)))^(1/(alfa-1));
Ym  =   K^alfa*L^(1-alfa);
Y   =   Ym/vp;
In  =   delta*K;
G   =   omega_g*Y;
Rk  =   (alfa*Pm*Ym/K+(1-delta)*Q)/Q;
W   =   (1-alfa)*Pm*Ym/L;
C   =   (1-omega_g)*Y - delta*K - tau*psi_bar*K;
Z   =   K;
f   =   0;
fprime = 0;

%Government
b   =   zetta*W;
psi =   psi_bar;
i   =   R*Pi-1;


%Private banks
Gamma   =   1-theta + lambda*theta*phi;
eta     =   Lambda*Gamma*R;
nu      =   Lambda*Gamma*(RkmR);
Omega   =  (1-psi_bar)*Q*Z/phi;
V       =   nu*Q*Z + eta*Omega;
Q_Z     =   Q*Z;
V1      =   nu*Q*Z;
V2      =   eta*Omega;

%Rest
lambda_c = 1/(C*(1-h))*(1-betta*h);
g1  =   lambda_c*Ym*Pistar/(1-betta*theta_p*Pi^((chi-1)*(1-epsilon_p)));
g2  =   lambda_c*Ym*Pm/(1-betta*theta_p*Pi^((chi-1)*(-epsilon_p)));


%Creating cell array of variables
vars_cell   =   {'L';'C';'Z';'K';'Ym';'In';'Y';'R';'Rk';'Q';'Pm';'vp';'Pi'...
    ;'Pistar';'W';'b';'i';'lambda_c';'Lambda';'phi';'eta';'nu';'Omega';'Gamma';'f';'fprime';'g1';'g2'...
    ;'psi';'G';'V';'Q_Z';'V1';'V2'};
nn_vars     =   length(vars_cell);

%Creating cell array of exogenous variables
varexo_cell =  {'Itilde'};
nn_varexo  =   length(varexo_cell);


%Creating a structure with the variables
nn_vars      =  length(vars_cell);
for ii=1:nn_vars
    eval(['vars.' vars_cell{ii} '=' vars_cell{ii} ';']);
end;


%Creating a structure with the variables
nn_varexo      =  length(varexo_cell);
for ii=1:nn_varexo
    eval(['varexo.' varexo_cell{ii} '=' varexo_cell{ii} ';']);
end;

