%Acurio, Damette, Shanafelt Model (2020)
%Sets the parameters, saves them to dynare/params.mat file

%Created by Veronica Acurio Vasconez
%July 2020

%Set parameters by allowing changes in a selection of economic ones
%Order (risk_premium,leverage,zeta,omega,h)
%baseline US (0.01/4,4,0.5,10,0.71)
%baseline EU (0.01/4,4,0.5,10,0.591)


function [params,moments,initial_SAIR,initial_SIR,initial_SIRS,initial_SIS,switches] = params_set(eco)


switch_print    =   'no';  %'test' for too many details, 'details', 'yes', 'no'

%%%%%%%%%%%%%%%%%%%%
%Setting parameters
%%%%%%%%%%%%%%%%%%%%

%Epidemiological block
alphav=0.4;     % transmision rate
betav=0.2;      %asymptomatic transition rate
gammav=0.1;     % recovery rate
epsilonv=0.05;  % immunity (return to susceptible)

%Initial conditions for SAIR
S_initial_SAIR      = 0.9;
Atilde_initial_SAIR = 0.07;
Itilde_initial_SAIR = 0.03;
Rtilde_initial_SAIR = 0;

%Initial conditions for SIR
S_initial_SIR      = 0.9;
Itilde_initial_SIR = 0.1;
Rtilde_initial_SIR = 0;

%Initial conditions for SIRS
S_initial_SIRS      = 0.9;
Itilde_initial_SIRS = 0.1;
Rtilde_initial_SIRS = 0;

%Initial conditions for SIS
S_initial_SIS      = 0.9;
Itilde_initial_SIS = 0.1;

%Househods
betta   =   0.99;            %Discount rate
h      =   eco(5);            %Internal habit formation

%Targeted moments
    RkmR_mom =  eco(1);    %steady state premium
    phi_mom  =  eco(2);         %steady state leverage
    R_mom     = 1/betta;      %steady state of gros interest rate
    Lambda_mom =    betta;       %steady state of stochastic discount factor    

%Credit policy parameters
tau     =   0.001;  %Efficient costs of credit policy
psi_bar =   0;      %fraction of publicly intermediated assets 
omega   =   eco(4);     %feedback parameter

%Private banks
theta   =   0.975;     %The survival probability
lambda = (1-theta)*(phi_mom*Lambda_mom*RkmR_mom + Lambda_mom*R_mom) ...
    / (phi_mom*(1 - phi_mom*Lambda_mom*theta*RkmR_mom - Lambda_mom*theta*R_mom));  %share of diverting funds
epsilon = (1-psi_bar)*(1-theta*(RkmR_mom*phi_mom+R_mom))/phi_mom; %share of startup funds

%Intermediate goods producers
alfa    =   0.33;           %Capital share
delta   =   0.025;          %Depreciation rate
omega_g     =   0.15;       %Government expenditures

%Capital producers
kappa   =   6.962;          %investment adjustment cost constant

%Retail firms
epsilon_p =   4.167;        %Elasticity of substitution between goods
theta_p   =   0.905;        %Calvo parameter
chi       =   0.477;        %Price indexation parameter

%Monetary Policy and Government
zetta   =   eco(3);            %share of unemployment benefit
phi_i   =   0.956;             %Interest rate smoothing parameter
phi_pi  =   1.688;             %Inflation coefficient
phi_y   =   0.098;             %Output gap coefficient


%Creating a structure for the parameters
params.alphav    = alphav;
params.betav    = betav;
params.gammav   = gammav;
params.epsilonv = epsilonv;  

params.betta     =   betta;
params.h        =   h;

params.theta    =  theta;     
params.lambda   =  lambda;           
params.epsilon  =  epsilon;

params.alfa    =   alfa;           
params.delta   =   delta;          
params.omega_g     =   omega_g;            

params.kappa   =   kappa;          

params.epsilon_p =   epsilon_p;       
params.theta_p   =   theta_p;        
params.chi       =   chi;            

params.zetta   =   zetta;            
params.phi_i   =   phi_i;            
params.phi_pi  =   phi_pi;            
params.phi_y   =   phi_y;         

params.tau     =   tau;  
params.omega   =   omega;     
params.psi_bar  =   psi_bar;      

%params.rho_c       =   rho_c;        
%params.sigma_c     =   sigma_c;          
%params.rho_a       =   rho_a;       
%params.sigma_a     =   sigma_a;          
%params.rho_k       =   rho_k ;       
%params.sigma_k     =   sigma_k;       
%params.rho_i       =   rho_i ;       
%params.sigma_i     =   sigma_i;  
%params.rho_ag      =   rho_ag;        
%params.rho_g       =   rho_g;        
%params.sigma_g     =   sigma_g;  
%params.sigma_v     =   sigma_v;


%Setting target moments
moments.RkmR_mom =   RkmR_mom;
moments.phi_mom  =   phi_mom;
moments.R_mom    =   R_mom;

%Setting initial conditions for each epidemic
initial_SAIR.S_initial      = S_initial_SAIR;
initial_SAIR.Atilde_initial = Atilde_initial_SAIR;
initial_SAIR.Itilde_initial = Itilde_initial_SAIR;
initial_SAIR.Rtilde_initial = Rtilde_initial_SAIR;

initial_SIR.S_initial      = S_initial_SIR;
initial_SIR.Itilde_initial = Itilde_initial_SIR;
initial_SIR.Rtilde_initial = Rtilde_initial_SIR;

initial_SIRS.S_initial      = S_initial_SIRS;
initial_SIRS.Itilde_initial = Itilde_initial_SIRS;
initial_SIRS.Rtilde_initial = Rtilde_initial_SIRS;

initial_SIS .S_initial      = S_initial_SIS;
initial_SIS .Itilde_initial = Itilde_initial_SIS;

switches.switch_print   =   switch_print;

cd ..
save Settings/params.mat params moments initial_SAIR initial_SIR initial_SIRS initial_SIS switches;

